/*
 * Paraselene
 * Copyright (c) 2009-2011  Akira Terasaki
 * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
 * 利用可能です。
 */
package paraselene.supervisor;



/**
 * Ajax 系操作の Forward を表します。
 */
public interface AjaxForward {
	/**
	 * 同じ動作であるか？
	 * @param o 比較対象。
	 * @return true:同一動作、false:異なる動作。
	 */
	boolean equals( Object o );
	/**
	 * 遷移先ページの取得。
	 * @return 遷移先のページID。エラー指定やリダイレクトの場合、nullを返します。
	 */
	PageID getPageID();
}

